package com.willshex.android.fingerspell;

import java.lang.Thread.UncaughtExceptionHandler;

import com.willshex.android.fingerspell.utilities.SettingsUtility;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class FingerSpell extends Activity implements LoadsDictionary {

	private ProgressDialog loading;
	private Handler callbackHandler = new Handler();
	private static final int SettingsRequestCode = 1;

	private final Runnable startLoading = new Runnable() {

		@Override
		public void run() {
			loading = new ProgressDialog(FingerSpell.this);
			loading.setCancelable(false);

			loading.setMessage(getString(
					R.string.androidfingerspell_loading_dictionary,
					SettingsUtility.getWordEngineName(FingerSpell.this)));
			loading.show();

			return;
		}
	};

	private final Runnable doneLoading = new Runnable() {

		@Override
		public void run() {
			if (loading.isShowing()) {
				loading.dismiss();
			}

			return;
		}
	};

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == SettingsRequestCode) {
			DictionaryPreloader.load(this, this);
		}

		return;
	}

	@Override
	public void startLoading() {
		callbackHandler.post(startLoading);

		return;
	}

	@Override
	public void doneLoading() {
		callbackHandler.post(doneLoading);

		return;
	}

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		Thread.setDefaultUncaughtExceptionHandler(new UncaughtExceptionHandler() {

			@Override
			public void uncaughtException(Thread thread, Throwable ex) {

				ex.printStackTrace();

				return;
			}
		});

		DictionaryPreloader.load(this, this);

		((Button) findViewById(R.id.ButtonTeachMe))
				.setOnClickListener(new OnClickListener() {

					@Override
					public void onClick(View v) {
						Intent intent = new Intent(FingerSpell.this,
								com.willshex.android.fingerspell.TeachMe.class);
						startActivity(intent);
					}
				});

		((Button) findViewById(R.id.ButtonTestMe))
				.setOnClickListener(new OnClickListener() {

					@Override
					public void onClick(View v) {
						Intent intent = new Intent(FingerSpell.this,
								com.willshex.android.fingerspell.TestMe.class);
						startActivity(intent);
					}
				});
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.main_menu, menu);

		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		boolean processed = false;

		Toast some = Toast.makeText(getApplicationContext(),
				"Selected " + item.getTitle(), 3);
		if (item.getTitle().equals(getString(R.string.main_menu_about))) {
			processed = true;
			some.show();
		} else if (item.getTitle().equals(getString(R.string.main_menu_help))) {
			processed = true;
			some.show();
		} else if (item.getTitle().equals(
				getString(R.string.main_menu_settings))) {
			processed = true;
			some.show();

			Intent intent = new Intent(FingerSpell.this,
					com.willshex.android.fingerspell.FingerspellSettings.class);
			startActivityForResult(intent, SettingsRequestCode);
		}

		return processed;
	}
}