package com.willshex.android.fingerspell.utilities;

import java.io.IOException;

import org.bithir.fingerspell.TextWordEngine;
import org.bithir.fingerspell.WordEngine;

import android.app.Activity;
import android.app.Application;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;

import com.willshex.android.fingerspell.FingerspellSettings;

/**
 * 
 * @author billy1380
 * 
 */
public class SettingsUtility {

	public static final String WORDLIST_KEY = "androidfingerspell_wordlist";
	public static final String SPEED_KEY = "androidfingerspell_speed";
	public static final String MAXWORDS_KEY = "androidfingerspell_maxWords";
	public static final String SIGNTYPEHAND_KEY = "androidfingerspell_signTypeHand";
	public static final String USEMULTICHOICE_KEY = "androidfingerspell_useMultichoice";

	private static WordEngine words = null;
	private static String wordEngineName = "";

	public static String getString(String key, String defValue,
			Activity activity) {
		String setting;

		SharedPreferences prefs = activity.getSharedPreferences(
				FingerspellSettings.SHARED_PREFERENCES_NAME,
				Application.MODE_PRIVATE);

		setting = prefs.getString(key, defValue);

		return setting;
	}

	public static int getInt(String key, int defValue, Activity activity) {
		int setting;

		SharedPreferences prefs = activity.getSharedPreferences(
				FingerspellSettings.SHARED_PREFERENCES_NAME,
				Application.MODE_PRIVATE);

		setting = prefs.getInt(key, defValue);

		return setting;
	}

	public static int getSpeed(Activity activity) {
		return SettingsUtility.getInt(SPEED_KEY, 1000, activity);
	}

	public static WordEngine getWordEngine(Activity activity) {
		String wordEngineName = getWordEngineName(activity);

		if (!wordEngineName.equals(SettingsUtility.wordEngineName)) {
			SettingsUtility.wordEngineName = wordEngineName;

			words = new TextWordEngine();

			try {
				words
						.LoadWordEngineFromResource(SettingsUtility.wordEngineName);
			} catch (IOException e) {
				e.printStackTrace();
			}
		}

		return words;
	}

	public static String getWordEngineName(Activity activity) {
		return getString(WORDLIST_KEY, "extensive_wordlist",
				activity);
	}
	
	public static void setInt(String key, int value, Activity activity) {
		Editor editor = activity.getSharedPreferences(
				FingerspellSettings.SHARED_PREFERENCES_NAME,
				Application.MODE_PRIVATE).edit();
		editor.putInt(key, value);
		editor.commit();

		return;
	}

	public static void setSpeed(int speed, Activity activity) {
		SettingsUtility.setInt(SPEED_KEY, speed, activity);
		return;
	}
}
