package com.willshex.android.fingerspell.views;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.View;

import com.toolkits.libsvgandroid.SvgRaster;
import com.willshex.android.fingerspell.LetterProvider;

public class SvgView extends View {

	public enum Mode {
		Test, Teach
	};

	private String letter = null;
	private long svgId;
	private int width, height;

	private Mode mode = Mode.Test;

	public Mode getMode() {
		return mode;
	}

	public void setMode(Mode mode) {
		this.mode = mode;
	}

	public String getLetter() {
		return letter;
	}

	public void setLetter(String letter) {
		this.letter = letter.toLowerCase();

		try {
			InputStream is = LetterProvider.getLetterSvg(this.letter);

			StringBuilder sb = new StringBuilder();
			String line;
			BufferedReader reader = new BufferedReader(new InputStreamReader(
					is, "UTF-8"));
			while ((line = reader.readLine()) != null) {
				sb.append(line).append("\n");
			}
			svgId = SvgRaster.svgAndroidCreate();
			SvgRaster.svgAndroidParseBuffer(svgId, sb.toString());
			SvgRaster.svgAndroidSetAntialiasing(svgId, true);
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		return;
	}

	public SvgView(Context context) {
		super(context);
	}

	public SvgView(Context context, AttributeSet attrs) {
		super(context, attrs);
	}

	public SvgView(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
	}

	@Override
	protected void onLayout(boolean changed, int left, int top, int right,
			int bottom) {
		// get visible area
		width = right - left;
		height = bottom - top;

		return;
	}

	@Override
	public void onDraw(Canvas canvas) {
		// paint a white background...
		canvas.drawColor(Color.WHITE);
		// OK, rasterise the SVG data
		// SvgRaster.svgAndroidRender(svgId, canvas);

		if (letter != null) {
			try {

				if (mode == Mode.Teach) {
					Paint paint = new Paint();
					paint.setColor(Color.LTGRAY);
					paint.setTextSize(250);

					paint.setSubpixelText(true);
					paint.setAntiAlias(true);

					paint.setFakeBoldText(true);

					Rect togetherBounds = new Rect();

					String together = letter.toUpperCase() + letter;
					paint.getTextBounds(together, 0, 2,
							togetherBounds);

					canvas.drawText(together, 20.0f,
							200.0f, paint);
				}
				
//				Matrix matrix = new Matrix();
//				matrix.setScale(1, -1);
//				canvas.save(Canvas.MATRIX_SAVE_FLAG);
//				canvas.concat(matrix);
				SvgRaster.svgAndroidRenderToArea(svgId, canvas, 0, 0, width,
						height);
//				canvas.restore();
				
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

}
