package org.bithir.fingerspell;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.Random;
import java.util.zip.GZIPInputStream;

/**
 * 
 * @author bithir
 */
public class TextWordEngine implements WordEngine {

	private String[] words = null;
	private Random randomizer = new Random();
	private int currentWord = 0;

	public static final String Alphabet = "abcdefghijklmnopqrstuvwxyz";
	
	private int[] newLetterStart = new int[Alphabet.length() + 1];

	public void LoadWordEngineFromResource(String name) throws IOException {
		URL url = TextWordEngine.class
				.getResource("/org/bithir/fingerspell/words/" + name
						+ ".txt.gz");
		LoadWordEngineFromStream(new GZIPInputStream(url.openStream()));
	}

	public void LoadWordEngineFromFile(File f) throws IOException {
		LoadWordEngineFromStream(new FileInputStream(f));
	}

	private void LoadWordEngineFromStream(InputStream s) throws IOException {
		BufferedReader br = new BufferedReader(new InputStreamReader(s));
		ArrayList<String> allWords = new ArrayList<String>();
		String word = null;
		char currentCharacter = Alphabet.charAt(0), firstCharacter = '\0';
		int wordCount = 0;
		int nthLetter = 0;

		while ((word = br.readLine()) != null) {
			word = word.trim();
			firstCharacter = Character.toLowerCase(word.charAt(0));
			if (firstCharacter != currentCharacter) {
				currentCharacter = firstCharacter;
				newLetterStart[nthLetter++] = wordCount;
			}

			allWords.add(word);
			wordCount++;
		}

		newLetterStart[Alphabet.length() - 1] = wordCount;

		words = new String[allWords.size()];
		allWords.toArray(words);
		currentWord = 0;
	}

	@Override
	public String getNextRandomWord() {
		currentWord = randomizer.nextInt(words.length);
		return getCurrentWord();
	}

	@Override
	public String getCurrentWord() {
		// protection against out of synch
		if (words != null && words.length > currentWord) {
			return words[currentWord];
		}
		return null;

	}

	@Override
	public String getWordStartingWith(char c) {

		int letterAt = Alphabet.indexOf(Character.toLowerCase(c));
		int minNum = 0;
		int maxNum = 0;

		if (letterAt != 0) {
			minNum = newLetterStart[letterAt - 1];
		}

		maxNum = newLetterStart[letterAt];

		currentWord = randomizer.nextInt(maxNum - minNum) + minNum;

		return getCurrentWord();
	}
}
